
# Class: ReferenceDtype




URI: [nwb_schema_language:ReferenceDtype](https://w3id.org/p2p_ld/nwb-schema-language/ReferenceDtype)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[ReferenceDtype&#124;target_type:string;reftype:reftype_options%20%3F])](https://yuml.me/diagram/nofunky;dir:TB/class/[ReferenceDtype&#124;target_type:string;reftype:reftype_options%20%3F])

## Attributes


### Own

 * [target_type](target_type.md)  <sub>1..1</sub>
     * Description: Describes the neurodata_type of the target that the reference points to
     * Range: [String](types/String.md)
 * [reftype](reftype.md)  <sub>0..1</sub>
     * Description: describes the kind of reference
     * Range: [reftype_options](reftype_options.md)
